@@ -1,5 +1,5 @@
 /*************************************************************************************
- *  Copyright (C) 2007 by Aleix Pol <aleixpol@gmail.com>                             *
+ *  Copyright (C) 2007 by Aleix Pol <aleixpol@kde.org>                               *
  *                                                                                   *
  *  This program is free software; you can redistribute it and/or                    *
  *  modify it under the terms of the GNU General Public License                      *
@@ -22,6 +22,9 @@
 #include "object.h"
 #include "analitzaexport.h"
 
+namespace Analitza
+{
+
 /** The Operator class is the operator representation in the trees. */
 class ANALITZA_EXPORT Operator : public Object
 {
@@ -47,7 +50,7 @@ class ANALITZA_EXPORT Operator : public Object
 			exp, ln, log,
 // 			conjugate, arg, real, imaginary,
 			sum, product, diff,
-			card, scalarproduct, selector,
+			card, scalarproduct, selector, _union,
 			function, nOfOps
 		};
 		/** Constructor. Creates an operator with @p t type .*/
@@ -57,16 +60,13 @@ class ANALITZA_EXPORT Operator : public Object
 		virtual ~Operator() {}
 		
 		/** Sets an operator type to the object */
-		void setOperator(enum OperatorType t) { m_optype=t; }
+		void setOperator(OperatorType t) { m_optype=t; }
 		
 		/** Returns the number of params expected for the operator type. */
 		int nparams() const { return nparams(m_optype); }
 		
 		/** Returns the operator type. */
-		enum OperatorType operatorType() const { return m_optype; }
-		
-		/** Returns this operator precedence. */
-		unsigned int weight() const { return operatorWeight(m_optype); }
+		OperatorType operatorType() const { return m_optype; }
 		
 		/** Returns the string expression representation of the operator. */
 		QString name() const;
@@ -98,26 +98,26 @@ class ANALITZA_EXPORT Operator : public Object
 		/** Returns the multiplicity operator of an operator @p t. e.g. 5+5+5+5=5*4 -> times is the multiplicityOperator of plus. */
 		static OperatorType multiplicityOperator(const OperatorType& t);
 		
-		/** Returns this operator @p o precedence. */
-		static unsigned int operatorWeight(OperatorType o);
-		
 		/** Converts a @p s operator tag to the operator. */
-		static enum OperatorType toOperatorType(const QString &s);
-		
-		/** Returns the expected number of parameters of a type. If there can be multiple parameters, -1 is returned */
-		static int nparams(enum OperatorType);
-		
-		/** Returns if it is a trigonometric operator. */
-		static bool isTrigonometric(enum OperatorType o);
+		static OperatorType toOperatorType(const QString &s);
 		
 		virtual bool matches(const Object*, QMap<QString, const Object*>*) const;
+		virtual bool decorate(const QMap< QString, Object** >& ) { return false; }
 		
 		virtual QString visit(ExpressionWriter*) const;
 		virtual Object* copy() const;
 		
 		static const char words[nOfOps][14];
 	private:
-		enum OperatorType m_optype;
+		/** Returns if it is a trigonometric operator. */
+		static bool isTrigonometric(OperatorType o);
+		
+		/** Returns the expected number of parameters of a type. If there can be multiple parameters, -1 is returned */
+		static int nparams(OperatorType o);
+		
+		OperatorType m_optype;
 };
 
+}
+
 #endif
