@@ -1,5 +1,5 @@
 /*************************************************************************************
- *  Copyright (C) 2008 by Aleix Pol <aleixpol@gmail.com>                             *
+ *  Copyright (C) 2008 by Aleix Pol <aleixpol@kde.org>                               *
  *                                                                                   *
  *  This program is free software; you can redistribute it and/or                    *
  *  modify it under the terms of the GNU General Public License                      *
@@ -20,11 +20,15 @@
 #define STRINGEXPRESSIONWRITER_H
 
 #include "expressionwriter.h"
+#include "operator.h"
+
+namespace Analitza
+{
 
 /**
  *	This class represents the string expression writer.
  *
- *	@author Aleix Pol <aleixpol@gmail.com>
+ *	@author Aleix Pol <aleixpol@kde.org>  
  */
 
 class StringExpressionWriter : public ExpressionWriter
@@ -37,11 +41,15 @@ class StringExpressionWriter : public ExpressionWriter
 		virtual QString accept(const Container* var);
 		virtual QString accept(const Operator* var);
 		virtual QString accept(const Vector* var);
+		virtual QString accept(const List* l);
 		
 		QString result() const { return m_result; }
 		
+		static int weight(const Operator* op, int size);
+		static const QMap<Operator::OperatorType, QString> s_operators;
 	private:
 		QString m_result;
 };
 
+}
 #endif
