@@ -278,22 +278,23 @@ void INDIStdDevice::setTextValue(INDI_P *pp)
 	}
 
 	// Update KStars Location once we receive update from INDI, if the source is set to DEVICE
-	if (Options::useDeviceSource())
-	{
+	if (Options::useDeviceSource()) {
 		dms lng, lat;
 
-	        el = pp->findElement("LONG");
-	        if (!el) return;
-	        sscanf(el->text.toAscii().data(), "%d%*[^0-9]%d%*[^0-9]%d", &d, &min, &sec);
+        el = pp->findElement("LONG");
+        if (!el)
+            return;
+        sscanf(el->text.toAscii().data(), "%d%*[^0-9]%d%*[^0-9]%d", &d, &min, &sec);
 		lng.setD(d,min,sec);
 
 		el = pp->findElement("LAT");
-	        if (!el) return;
-	        sscanf(el->text.toAscii().data(), "%d%*[^0-9]%d%*[^0-9]%d", &d, &min, &sec);
+        if (!el)
+            return;
+        sscanf(el->text.toAscii().data(), "%d%*[^0-9]%d%*[^0-9]%d", &d, &min, &sec);
 		lat.setD(d,min,sec);
 		
-	        ksw->geo()->setLong(lng);
-		ksw->geo()->setLat(lat);
+        ksw->data()->geo()->setLong(lng);
+        ksw->data()->geo()->setLat(lat);
 	}
         break;
 
@@ -323,7 +324,7 @@ void INDIStdDevice::setTextValue(INDI_P *pp)
         el = pp->findElement("DEC");
         if (!el) return;
         telescopeSkyObject->setDec(el->value);
-        telescopeSkyObject->EquatorialToHorizontal(ksw->LST(), ksw->geo()->lat());
+        telescopeSkyObject->EquatorialToHorizontal(ksw->data()->lst(), ksw->data()->geo()->lat());
 
         if (ksw->map()->focusObject() == telescopeSkyObject)
             ksw->map()->updateFocus();
@@ -340,7 +341,7 @@ void INDIStdDevice::setTextValue(INDI_P *pp)
         el = pp->findElement("AZ");
         if (!el) return;
         telescopeSkyObject->setAz(el->value);
-        telescopeSkyObject->HorizontalToEquatorial(ksw->LST(), ksw->geo()->lat());
+        telescopeSkyObject->HorizontalToEquatorial(ksw->data()->lst(), ksw->data()->geo()->lat());
         // Force immediate update of skymap if the focus object is our telescope.
         if (ksw->map()->focusObject() == telescopeSkyObject)
             ksw->map()->updateFocus();
@@ -518,7 +519,7 @@ void INDIStdProperty::newTime()
     timeEle = pp->findElement("UTC");
     if (!timeEle) return;
 
-    TimeDialog timedialog ( ksw->data()->ut(), ksw->geo(), ksw, true );
+    TimeDialog timedialog ( ksw->data()->ut(), ksw->data()->geo(), ksw, true );
 
     if ( timedialog.exec() == QDialog::Accepted )
     {
@@ -538,7 +539,7 @@ void INDIStdProperty::newTime()
     timeEle = SDProp->findElement("LST");
     if (!timeEle) return;
 
-    timeEle->write_w->setText(ksw->LST()->toHMSString());
+    timeEle->write_w->setText(ksw->data()->lst()->toHMSString());
     SDProp->newText();
 }
 
@@ -586,7 +587,7 @@ void INDIStdDevice::updateLocation()
 {
     INDI_P *pp;
     INDI_E * latEle, * longEle;
-    GeoLocation *geo = ksw->geo();
+    GeoLocation *geo = ksw->data()->geo();
 
     pp = dp->findProp("GEOGRAPHIC_COORD");
     if (!pp) return;
@@ -1002,11 +1003,12 @@ bool INDIStdProperty::actionTriggered(INDI_E *lp)
 
                 if (prop == NULL)
                 {
-		    // Backward compatibility
-                    prop = pp->pg->dp->findProp("HORIZONTAL_COORD");
+
+                    prop = pp->pg->dp->findProp("HORIZONTAL_COORD_REQUEST");
                     if (prop == NULL)
 		    {
-			prop = pp->pg->dp->findProp("HORIZONTAL_COORD_REQUEST");
+  		        // Backward compatibility
+			prop = pp->pg->dp->findProp("HORIZONTAL_COORD");
 			if (prop == NULL)
                         	return false;
 		    }
