@@ -37,8 +37,16 @@ bool SatelliteComponent::selected()
     return Options::showSatellites();
 }
 
+void SatelliteComponent::init() {
+    Q_ASSERT( false &&
+              "This code should never execute and even better exist\n\n"
+              "If program crashed and you see this message it is a bug\n\n"
+              "Sorry for any inconvenience (-:"
+        );
+}
 
-void SatelliteComponent::init( const QString &name, KStarsData *data, SPositionSat *pSat[], int npos ) {
+void SatelliteComponent::initSat( const QString &name, SPositionSat *pSat[], int npos ) {
+    KStarsData *data = KStarsData::Instance();
     setLabel( name );
     setLabelPosition( LineListComponent::RightEdgeLabel );
 
