@@ -28,7 +28,6 @@
 #include "kstars.h"
 #include "kstarsdata.h"
 #include "skyobjects/skypoint.h"
-#include "ksutils.h"
 #include "ksnumbers.h"
 #include "dialogs/finddialog.h"
 #include "widgets/dmsbox.h"
@@ -40,9 +39,8 @@ modCalcEclCoords::modCalcEclCoords(QWidget *parentSplit)
     RA->setDegType(false);
 
     //Initialize Date/Time and Location data
-    KStars *ks = ((KStars*) topLevelWidget()->parent());
-    DateTime->setDateTime( ks->data()->lt().dateTime() );
-    kdt = ((KStarsDateTime)DateTime->dateTime());
+    DateTime->setDateTime( KStarsData::Instance()->lt().dateTime() );
+    kdt = DateTime->dateTime();
 
     connect(NowButton, SIGNAL(clicked()), this, SLOT(slotNow()));
     connect(ObjectButton, SIGNAL(clicked()), this, SLOT(slotObject()));
@@ -72,7 +70,7 @@ void modCalcEclCoords::slotNow() {
 }
 
 void modCalcEclCoords::slotObject() {
-    QPointer<FindDialog> fd = new FindDialog( (KStars*)topLevelWidget()->parent() );
+    QPointer<FindDialog> fd = new FindDialog( KStars::Instance() );
     if ( fd->exec() == QDialog::Accepted ) {
         SkyObject *o = fd->selectedObject();
         RA->showInHours( o->ra() );
