@@ -24,7 +24,6 @@
 
 class QTime;
 class GeoLocation;
-class KStars;
 
 /**
   * Class which implements the KStars calculator module to compute Universal
@@ -35,11 +34,8 @@ class KStars;
 	*@version 0.9
   */
 class modCalcSidTime : public CalcFrame, public Ui::modCalcSidTimeDlg  {
-
     Q_OBJECT
-
 public:
-
     modCalcSidTime(QWidget *p);
     ~modCalcSidTime();
 
@@ -70,7 +66,6 @@ private:
 
     bool bSyncTime;
     GeoLocation *geo, *geoBatch;
-    KStars *ks;
 };
 
 #endif
