@@ -14,10 +14,10 @@
 #include "LayerManager.h"
 
 // Qt
-#include <QtCore/QDebug>
 #include <QtGui/QAction>
 
 // Local dir
+#include "MarbleDebug.h"
 #include "AbstractDataPlugin.h"
 #include "AbstractDataPluginItem.h"
 #include "AbstractFloatItem.h"
@@ -59,6 +59,11 @@ LayerManager::LayerManager( MarbleDataFacade* dataFacade, QObject *parent )
 
     // get float items and data plugins
     foreach( RenderPlugin * renderPlugin, d->m_renderPlugins ) {
+        connect( renderPlugin, SIGNAL( settingsChanged( QString ) ),
+                 this, SIGNAL( pluginSettingsChanged() ) );
+        connect( renderPlugin, SIGNAL( repaintNeeded( QRegion ) ),
+                 this, SIGNAL( repaintNeeded( QRegion ) ) );
+
         AbstractFloatItem * const floatItem =
             qobject_cast<AbstractFloatItem *>( renderPlugin );
         if ( floatItem )
@@ -73,7 +78,6 @@ LayerManager::LayerManager( MarbleDataFacade* dataFacade, QObject *parent )
     // Just for initial testing
     foreach( RenderPlugin * renderPlugin, d->m_renderPlugins ) {
         renderPlugin->setDataFacade( d->m_dataFacade );
-        renderPlugin->initialize();
     }
 }
 
@@ -100,11 +104,19 @@ QList<AbstractDataPlugin *> LayerManager::dataPlugins() const
     return d->m_dataPlugins;
 }
 
-QList<AbstractDataPluginItem *> LayerManager::whichItemAt( const QPoint& curpos ) const {
+QList<AbstractDataPluginItem *> LayerManager::whichItemAt( const QPoint& curpos ) const
+{
     QList<AbstractDataPluginItem *> itemList;
     
     foreach( AbstractDataPlugin *plugin, d->m_dataPlugins ) {
+#if QT_VERSION >= 0x040500
         itemList.append( plugin->whichItemAt( curpos ) );
+#else
+        QList<AbstractDataPluginItem *> subList =  plugin->whichItemAt( curpos );
+        foreach( AbstractDataPluginItem *item, subList ) {
+            itemList.append( item );
+        }
+#endif
     }
     return itemList;
 }
@@ -121,7 +133,7 @@ void LayerManager::renderLayer( GeoPainter *painter, ViewParams *viewParams,
                                 const QString& renderPosition )
 {
     if ( !viewParams || !viewParams->viewport() ) {
-        qDebug() << "LayerManager: No valid viewParams set!";
+        mDebug() << "LayerManager: No valid viewParams set!";
         return;
     }
 
@@ -130,6 +142,11 @@ void LayerManager::renderLayer( GeoPainter *painter, ViewParams *viewParams,
     foreach( RenderPlugin *renderPlugin, d->m_renderPlugins ) {
         if ( renderPlugin && renderPlugin->renderPosition().contains( renderPosition )  ){
             if ( renderPlugin->enabled() && renderPlugin->visible() ) {
+                if ( !renderPlugin->isInitialized() )
+                {
+                    renderPlugin->initialize();
+                    emit renderPluginInitialized( renderPlugin );
+                }
                 renderPlugin->render( painter, viewport, renderPosition );
             }
         }
@@ -156,11 +173,15 @@ void LayerManager::syncViewParamsAndPlugins( GeoSceneDocument *mapTheme )
             renderPlugin->setVisible( propertyValue );
         }
 
-        renderPlugin->disconnect();
+        disconnect( renderPlugin->action(), SIGNAL( changed() ),
+                 this,                   SIGNAL( floatItemsChanged() ) );
+        disconnect( renderPlugin, SIGNAL( visibilityChanged( QString, bool ) ),
+                 this,         SLOT( syncPropertyWithAction( QString, bool ) ) );
         connect( renderPlugin->action(), SIGNAL( changed() ), 
                  this,                   SIGNAL( floatItemsChanged() ) );
-        connect( renderPlugin, SIGNAL( valueChanged( QString, bool ) ),
+        connect( renderPlugin, SIGNAL( visibilityChanged( QString, bool ) ),
                  this,         SLOT( syncPropertyWithAction( QString, bool ) ) );
+
     }
 
     disconnect( mapTheme->settings(), 0, this, 0 );
