@@ -28,6 +28,7 @@
 
 #include "GeoDataLatLonAltBox.h"
 #include "GeoDataCoordinates.h"
+#include "marble_export.h"
 
 namespace Marble
 {
@@ -36,9 +37,7 @@ namespace Marble
 static const int tessellationPrecision = 10;
 static const int latLonAltBoxSamplingRate = 4;
 
-class AbstractProjectionHelper;
 class GeoDataLineString;
-class GeoDataLinearRing;
 class ViewportParams;
 class AbstractProjectionPrivate;
 
@@ -47,7 +46,7 @@ class AbstractProjectionPrivate;
  * @short A base class for all projections in Marble.
  */
 
-class AbstractProjection
+class MARBLE_EXPORT AbstractProjection
 {
     // Not a QObject so far because we don't need to send signals.
  public:
@@ -207,7 +206,10 @@ class AbstractProjection
 
     // The usage of the following methods is DEPRECATED!
 
-    /* DEPRECATED */
+    /**
+     * @deprecated
+     * use @see screenCoordinates(qreal,qreal,const ViewportParams*,qreal&,qreal&)
+     */
     bool screenCoordinates( qreal lon, qreal lat,
                                     const ViewportParams *viewport,
                                     int& x, int& y );
