@@ -54,6 +54,9 @@ class GEODATA_EXPORT GeoDataContainer : public GeoDataFeature
     /// Destruct the GeoDataContainer
     virtual ~GeoDataContainer();
 
+    /// Provides type information for downcasting a GeoData
+    virtual QString nodeType() const;
+
     /**
      * @brief A convenience function that returns all folders in this container.
      * @return A QVector of GeoDataFolder
@@ -75,7 +78,6 @@ class GEODATA_EXPORT GeoDataContainer : public GeoDataFeature
      * @return A QVector of GeoDataPlacemark
      *
      * @see GeoDataPlacemark
-     * @see PlacemarkContainer
      */
     QVector<GeoDataPlacemark> placemarks() const;
     
@@ -139,6 +141,7 @@ class GEODATA_EXPORT GeoDataContainer : public GeoDataFeature
     virtual void unpack( QDataStream& stream );
 private:
     friend class GeoDataDocument;
+    friend class GeoDataFolder;
     GeoDataContainer( GeoDataContainerPrivate *priv );
 };
 
