@@ -26,7 +26,6 @@
 namespace Marble
 {
 
-class GeoDataPointPrivate;
 
 /** 
  * @short A Geometry object representing a 3d point
@@ -45,12 +44,14 @@ class GeoDataPointPrivate;
 */
 
 class GEODATA_EXPORT GeoDataPoint : public GeoDataCoordinates,
-                                    public GeoDataGeometry {
+                                    public GeoDataGeometry
+{
  public:
     typedef GeoDataCoordinates::Notation Notation;
     typedef GeoDataCoordinates::Unit Unit;
 
     GeoDataPoint( const GeoDataPoint& other );
+    GeoDataPoint( const GeoDataCoordinates& other );
     GeoDataPoint( const GeoDataGeometry& other );
     GeoDataPoint();
 
@@ -67,6 +68,9 @@ class GEODATA_EXPORT GeoDataPoint : public GeoDataCoordinates,
 
     ~GeoDataPoint();
 
+    /// Provides type information for downcasting a GeoData
+    virtual QString nodeType() const;
+
     // Type definitions
     typedef QVector<GeoDataPoint> Vector;
 
