@@ -24,12 +24,18 @@
 
 #include "GeoTagHandler.h"
 
-class DgmlGroupTagHandler : public GeoTagHandler {
- public:
-    DgmlGroupTagHandler();
-    virtual ~DgmlGroupTagHandler();
+namespace Marble
+{
+namespace dgml
+{
 
+class DgmlGroupTagHandler : public GeoTagHandler
+{
+ public:
     virtual GeoNode* parse(GeoParser&) const;
 };
 
+}
+}
+
 #endif // DgmlGroupTagHandler_h
