@@ -21,7 +21,7 @@
 
 #include "DgmlItemTagHandler.h"
 
-#include <QtCore/QDebug>
+#include "MarbleDebug.h"
 
 #include "DgmlElementDictionary.h"
 #include "DgmlAttributeDictionary.h"
