@@ -24,9 +24,18 @@
 
 #include "GeoTagHandler.h"
 
-class DgmlProjectionTagHandler : public GeoTagHandler {
+namespace Marble
+{
+namespace dgml
+{
+
+class DgmlProjectionTagHandler : public GeoTagHandler
+{
 public:
     virtual GeoNode* parse( GeoParser& ) const;
 };
 
+}
+}
+
 #endif // DgmlProjectionTagHandler_h
