@@ -24,12 +24,18 @@
 
 #include "GeoTagHandler.h"
 
-class DgmlSettingsTagHandler : public GeoTagHandler {
- public:
-    DgmlSettingsTagHandler();
-    virtual ~DgmlSettingsTagHandler();
+namespace Marble
+{
+namespace dgml
+{
 
+class DgmlSettingsTagHandler : public GeoTagHandler
+{
+ public:
     virtual GeoNode* parse(GeoParser&) const;
 };
 
+}
+}
+
 #endif // DgmlSettingsTagHandler_h
