@@ -38,15 +38,13 @@ GeoNode* DgmlTargetTagHandler::parse(GeoParser& parser) const
     // Check whether the tag is valid
     Q_ASSERT(parser.isStartElement() && parser.isValidElement(dgmlTag_Target));
 
-    GeoSceneLayer *layer = 0;
-
     // Checking for parent item
     GeoStackItem parentItem = parser.parentElement();
     if (parentItem.represents(dgmlTag_Head))
         parentItem.nodeAs<GeoSceneHead>()->setTarget( parser.readElementText().trimmed() );
 
     if (parentItem.represents(dgmlTag_Map)) {
-/*        layer = new GeoSceneLayer( "$MARBLETARGET$" );
+/*        GeoSceneLayer *layer = new GeoSceneLayer( "$MARBLETARGET$" );
         parentItem.nodeAs<GeoSceneMap>()->addLayer( layer );*/
     }
 
