@@ -24,12 +24,18 @@
 
 #include "GeoTagHandler.h"
 
-class KmlopenTagHandler : public GeoTagHandler {
-public:
-    KmlopenTagHandler();
-    virtual ~KmlopenTagHandler();
+namespace Marble
+{
+namespace kml
+{
 
+class KmlopenTagHandler : public GeoTagHandler
+{
+public:
     virtual GeoNode* parse(GeoParser&) const;
 };
 
+}
+}
+
 #endif // KmlopenTagHandler_h
