@@ -24,12 +24,18 @@
 
 #include "GeoTagHandler.h"
 
-class KmlouterBoundaryIsTagHandler : public GeoTagHandler {
-public:
-    KmlouterBoundaryIsTagHandler();
-    virtual ~KmlouterBoundaryIsTagHandler();
+namespace Marble
+{
+namespace kml
+{
 
+class KmlouterBoundaryIsTagHandler : public GeoTagHandler
+{
+public:
     virtual GeoNode* parse(GeoParser&) const;
 };
 
+}
+}
+
 #endif // KmlouterBoundaryIsTagHandler_h
