@@ -24,12 +24,18 @@
 
 #include "GeoTagHandler.h"
 
-class KmlpopTagHandler : public GeoTagHandler {
-public:
-    KmlpopTagHandler();
-    virtual ~KmlpopTagHandler();
+namespace Marble
+{
+namespace kml
+{
 
+class KmlpopTagHandler : public GeoTagHandler
+{
+public:
     virtual GeoNode* parse(GeoParser&) const;
 };
 
+}
+}
+
 #endif // KmlpopTagHandler_h
