@@ -21,7 +21,7 @@ GpsdConnection::GpsdConnection( QObject* parent )
     gps_data_t* data = m_gpsd.open();
     if ( data ) {
 #if defined( GPSD_API_MAJOR_VERSION ) && ( GPSD_API_MAJOR_VERSION >= 3 ) && defined( WATCH_ENABLE )
-        m_gpsd.stream( WATCH_ENABLE );
+        m_gpsd.stream( WATCH_ENABLE | WATCH_NMEA );
 #endif
         connect( &m_timer, SIGNAL( timeout() ), this, SLOT( update() ) );
         m_timer.start( 1000 );
@@ -31,16 +31,18 @@ GpsdConnection::GpsdConnection( QObject* parent )
 
 void GpsdConnection::update()
 {
-    gps_data_t* data = 0;
-#if defined( GPSD_API_MAJOR_VERSION ) && ( GPSD_API_MAJOR_VERSION >= 3 ) && defined( POLICY_SET )
-    while ((data = m_gpsd.poll()) && !(data->set & POLICY_SET)) {
-        data = m_gpsd.poll();
+#if defined( GPSD_API_MAJOR_VERSION ) && ( GPSD_API_MAJOR_VERSION >= 3 ) && defined( PACKET_SET )
+    if ( m_gpsd.waiting() ) {
+        gps_data_t* data = m_gpsd.poll();
+        if ( data && data->set & PACKET_SET ) {
+            emit gpsdInfo( *data );
+        }
     }
 #else
-    data = m_gpsd.query( "o" );
-#endif
+    gps_data_t* data = m_gpsd.query( "o" );
     if ( data )
         emit gpsdInfo( *data );
+#endif
 }
 
 
